tag_subf: Extract content of subf of tag indicated by id from given...

Description Usage Arguments

View source: R/tags.R

Description

Extract content of subf of tag indicated by id from given item

Usage

1
tag_subf(item, id, subf, preserve = FALSE, collapse = FALSE)

Arguments

item

Item data parsed as picaxml or ppxml

id

Identifier of tag to be extracted

subf

Subfield identifier of tag to be extracted

preserve

Whether to preserve empty and duplicate values

collapse

Whether to collapse multiple values


herreio/picar documentation built on July 24, 2020, 2:07 p.m.